@@ -5,16 +5,14 @@ import datetime
 import dateutil.parser
 import os
 
-import unittest
-if not hasattr(unittest.TestCase, 'assertIsNotNone'):
-    import unittest2 as unittest
+from . import unittest
 
 
 class TestTimezoned(unittest.TestCase):
 
     def test_create_from_ical(self):
         directory = os.path.dirname(__file__)
-        cal = icalendar.Calendar.from_ical(open(os.path.join(directory, 'timezoned.ics'),'rb').read())
+        cal = icalendar.Calendar.from_ical(open(os.path.join(directory, 'timezoned.ics'), 'rb').read())
 
         self.assertEqual(cal['prodid'].to_ical(), "-//Plone.org//NONSGML plone.app.event//EN")
 
@@ -65,14 +63,14 @@ class TestTimezoned(unittest.TestCase):
 
         event = icalendar.Event()
         tz = pytz.timezone("Europe/Vienna")
-        event.add('dtstart', datetime.datetime(2012,02,13,10,00,00,tzinfo=tz))
-        event.add('dtend',  datetime.datetime(2012,02,17,18,00,00,tzinfo=tz))
-        event.add('dtstamp', datetime.datetime(2010,10,10,10,10,10,tzinfo=tz))
-        event.add('created', datetime.datetime(2010,10,10,10,10,10,tzinfo=tz))
+        event.add('dtstart', datetime.datetime(2012, 02, 13, 10, 00, 00, tzinfo=tz))
+        event.add('dtend', datetime.datetime(2012, 02, 17, 18, 00, 00, tzinfo=tz))
+        event.add('dtstamp', datetime.datetime(2010, 10, 10, 10, 10, 10, tzinfo=tz))
+        event.add('created', datetime.datetime(2010, 10, 10, 10, 10, 10, tzinfo=tz))
         event.add('uid', u'123456')
-        event.add('last-modified', datetime.datetime(2010,10,10,10,10,10,tzinfo=tz))
+        event.add('last-modified', datetime.datetime(2010, 10, 10, 10, 10, 10, tzinfo=tz))
         event.add('summary', u'artsprint 2012')
-        #event.add('rrule', u'FREQ=YEARLY;INTERVAL=1;COUNT=10')
+        # event.add('rrule', u'FREQ=YEARLY;INTERVAL=1;COUNT=10')
         event.add('description', u'sprinting at the artsprint')
         event.add('location', u'aka bild, wien')
         event.add('categories', u'first subject')
@@ -103,14 +101,17 @@ class TestTimezoned(unittest.TestCase):
         self.assertTrue("DTSTAMP;VALUE=DATE-TIME:20101010T091010Z" in test_out)
         self.assertTrue("CREATED;VALUE=DATE-TIME:20101010T091010Z" in test_out)
 
-
     def test_tzinfo_dateutil(self):
         # Test for issues #77, #63
-        # references: #73,7430b66862346fe3a6a100ab25e35a8711446717 
+        # references: #73,7430b66862346fe3a6a100ab25e35a8711446717
 
         date = dateutil.parser.parse('2012-08-30T22:41:00Z')
+        date2 = dateutil.parser.parse('2012-08-30T22:41:00 +02:00')
         self.assertTrue(date.tzinfo.__module__ == 'dateutil.tz')
+        self.assertTrue(date2.tzinfo.__module__ == 'dateutil.tz')
 
         # make sure, it's parsed properly and doesn't throw an error
         self.assertTrue(icalendar.vDDDTypes(date).to_ical()
                         == '20120830T224100Z')
+        self.assertTrue(icalendar.vDDDTypes(date2).to_ical()
+                        == '20120830T224100')
